@@ -1,6 +1,6 @@
-    # -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 # hmath
-# v.3.3.2
+# v.3.3.3
 # by caleb7023
 #
 #                                        ...(+uwXuuZuuZuuZZuZXA&J-..
@@ -58,62 +58,62 @@
 #
 
 """
-# [hmath](https://hmath.com/home)
+# [hmath](https://caleb7023.hmath.pro)
 
-![hmath](https://hmath.com/home)
+![hmath](https://caleb7023.hmath.pro)
 
 hmath was developed to use advanced math functions in python.
 You can use complex numbers for most functions.
 
 # Version
-v.3.3.2
+[v.3.3.4](https://caleb7023.hmath.pro/version/v-3-3-4)
 
 hmath is investigating whether the calculation of the function is correct and whether the calculation is efficient. 
 Please help us provide information on efficient calculation methods and whether the calculations are correct.
-[Click on this to answer.](https://hmath.com/Feedback-on-hmath-modules)
+[Click on this to answer.](https://caleb7023.hmath.pro/Feedback)
 
 
-[Feedback on hmath modules](https://hmath.com/Feedback-on-hmath-modules)
+[Feedback on hmath modules](https://caleb7023.hmath.pro/Feedback)
 """
 
 __corresponding_dictionary = {
-    "B"                    : {},
-    "O"                    : {},
-    "ln"                   : {},
-    "rad"                  : {},
-    "exp"                  : {},
-    "sin"                  : {},
-    "cos"                  : {},
-    "tan"                  : {},
-    "csc"                  : {},
-    "sec"                  : {},
-    "cot"                  : {},
-    "asin"                 : {},
-    "acos"                 : {},
-    "atan"                 : {},
-    "acsc"                 : {},
-    "asec"                 : {},
-    "acot"                 : {},
-    "sinh"                 : {},
-    "cosh"                 : {},
-    "tanh"                 : {},
-    "csch"                 : {},
-    "sech"                 : {},
-    "coth"                 : {},
-    "asinh"                : {},
-    "acosh"                : {},
-    "atanh"                : {},
-    "acsch"                : {},
-    "asech"                : {},
-    "acoth"                : {},
-    "Gamma"                : {},
-    "polyGamma"            : {},
-    "cube_root"            : {},
-    "factorial"            : {},
-    "square_root"          : {},
-    "primality_test"       : {},
-    "prime_factorization"  : {},
-    "reduction_of_fraction": {},
+    "B"                     : {},
+    "O"                     : {},
+    "ln"                    : {},
+    "rad"                   : {},
+    "exp"                   : {},
+    "sin"                   : {},
+    "cos"                   : {},
+    "tan"                   : {},
+    "csc"                   : {},
+    "sec"                   : {},
+    "cot"                   : {},
+    "asin"                  : {},
+    "acos"                  : {},
+    "atan"                  : {},
+    "acsc"                  : {},
+    "asec"                  : {},
+    "acot"                  : {},
+    "sinh"                  : {},
+    "cosh"                  : {},
+    "tanh"                  : {},
+    "csch"                  : {},
+    "sech"                  : {},
+    "coth"                  : {},
+    "asinh"                 : {},
+    "acosh"                 : {},
+    "atanh"                 : {},
+    "acsch"                 : {},
+    "asech"                 : {},
+    "acoth"                 : {},
+    "Gamma"                 : {},
+    "polyGamma"             : {},
+    "cube_root"             : {},
+    "factorial"             : {},
+    "square_root"           : {},
+    "primality_test"        : {},
+    "prime_factorization"   : {},
+    "reduction_of_fraction" : {},
 }
 
 def __memo(func):
@@ -151,6 +151,8 @@ def __list(func):
                     for process in len(args1):
                         value1 = args1[process]
                         ans += [func(value1)]
+            if type(args[0]) == array:
+                return array(ans)
             return ans
         except:
             if len(args) == 1:
@@ -188,8 +190,8 @@ class array:
     >>> hmath.array([3.1, -2.5, 9])
     array[ 3.1, -2.5,    9]
     >>> hmath.array([[3 + 5j, 3], [hmath.fraction(4, 3), -32]])
-    array[[ (3+5j),       3],
-          [(4 / 3),     -32]]
+    array[[ (3+5j),      3],
+          [(4 / 3),    -32]]
     """
     def __init__(self, array_list):
         if array.__size_check(array_list):
@@ -510,6 +512,21 @@ class fraction:
     def __rge__(self, other):
         return self > other or self == other
 
+@__memo
+def Sigma(_roop_time, _first_value, _formula):
+    ans = 0
+    for n in range(_first_value, _roop_time):
+        ans += eval(_formula)
+    return ans
+
+@__memo
+def Pi(_roop_time, _first_value, _formula):
+    ans = 0
+    for n in range(_first_value, _roop_time):
+        ans *= eval(_formula)
+    return ans
+
+@__memo
 @__list
 def reduction_of_fraction(_fr):
     """
@@ -716,7 +733,7 @@ def cube_root(_x):
 
 @__list
 @__memo
-def root_of(_x , _y):
+def radical(_x , _y):
     return _y ** (1 / _x)
 
 @__list
@@ -785,12 +802,34 @@ def cos(_θ, _n = 0):
 @__pow
 @__memo
 def tan(_θ, _n = 0):
+    """
+    "tan(θ)" returns value of tangent θ.
+    >>> hmath.tan(6)
+    (-0.29100619138474915+0j)
+    >>> hmath.tan(2.11)
+    (-1.671269119715739-0j)
+    >>> hmath.tan(53+12j)
+    (-5.490123633255438e-11+0.9999999999481682j)
+    >>> hmath.tan([2.14, 25, 33+5j])
+    [(-1.5628769600778225-0j), (-0.13352640702153587+0j), (-2.411059897354615e-06+1.0000907719652579j)]
+    """
     return div(sin(_θ) , cos(_θ))
 
 @__list
 @__pow
 @__memo
 def csc(_θ, _n = 0):
+    """
+    "csc(θ)" returns value of cosec θ.
+    >>> hmath.csc(6)
+    (-3.5788995472544056-0j)
+    >>> hmath.csc(2.11)
+    (1.1653411285319317+0j)
+    >>> hmath.csc(53+12j)
+    (4.865296397916956e-06+1.1284248877945188e-05j)
+    >>> hmath.csc([2.14, 25, 33+5j])
+    [(1.1871825621413237+0j), (-7.555623550585948-0j), (0.01347409494265443+0.00017889167746147676j)]
+    """
     return div(1 , sin(_θ))
 
 @__list
@@ -928,5 +967,3 @@ def degrees(_θ):
 @__memo
 def polyGamma(_x, _n = 0):
     return Gamma(_x, "d") / Gamma(_x)
-
-array([[7,8],[1,0],[3,6]])+array([[6,5],[9,3],[3,2]])
\ No newline at end of file
